==> nm-tray_0.4.3.orig.tar.gz: nm-tray-0.4.3/translations/nm-tray_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informations de connexion</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Dialogue</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Toutes les informations</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Connexions actives</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Sans-fil disponible</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="55"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - mot de passe sans-fil</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Mot de passe nécessaire pour la connexion à &apos;%1&apos; :</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="744"/>
        <source>root</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="746"/>
        <source>active connection(s)</source>
        <translation>connexion(s) active(s)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="748"/>
        <source>connection(s)</source>
        <translation>connexion(s)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="750"/>
        <source>device(s)</source>
        <translation>périphérique(s)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="752"/>
        <source>wifi network(s)</source>
        <translation>réseau(x) wifi</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1043"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>inconnu</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1151"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1154"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Adresse matérielle</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1156"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Pilote</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1158"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Vitesse</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1160"/>
        <source> Kb/s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1162"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>inconnu</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1166"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Sécurité</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1170"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1171"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1182"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1184"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Masque de sous-réseau</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1193"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Route par défaut</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1199"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Connexion &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Pas de connexion active&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Connexion perdue</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Plus connecté à %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Connexion établie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Connecté à présent à %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Activer le réseau</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Activer le Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Activer les notifications</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Informations de connexion</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Informations de débogage</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Wifi - demande d&apos;analyse</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Éditer les connexions...</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>Infos nm-tray</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>à propos de %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; est une interface graphique simple basée sur Qt pour &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version : %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Connexion(s) active(s)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Réseau(x) Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Connexion(s) connue(s)</translation>
    </message>
</context>
</TS>

==> nm-tray_0.5.1.orig.tar.gz: nm-tray-0.5.1/translations/nm-tray_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informations de connexion</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Dialogue</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Toutes les informations</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Connexions actives</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Sans-fil disponible</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - mot de passe sans-fil</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="57"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Mot de passe nécessaire pour la connexion à &apos;%1&apos; :</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="745"/>
        <source>root</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="747"/>
        <source>active connection(s)</source>
        <translation>connexion(s) active(s)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="749"/>
        <source>connection(s)</source>
        <translation>connexion(s)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="751"/>
        <source>device(s)</source>
        <translation>périphérique(s)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="753"/>
        <source>wifi network(s)</source>
        <translation>réseau(x) wifi</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1044"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>inconnu</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1155"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Adresse matérielle</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1157"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Pilote</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1159"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Vitesse</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Kb/s</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1165"/>
        <source>Mb/s</source>
        <translation>Mb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1167"/>
        <source>Gb/s</source>
        <translation>Gb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1169"/>
        <source>Tb/s</source>
        <translation>Tb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>inconnu</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1176"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Sécurité</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1180"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1192"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1194"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Masque de sous-réseau</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1203"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Route par défaut</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1209"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Connexion &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Pas de connexion active&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Connexion perdue</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Plus connecté à %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Connexion établie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Connecté à présent à %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Activer le réseau</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Activer le Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Activer les notifications</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Informations de connexion</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Informations de débogage</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Wifi - demande d&apos;analyse</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Éditer les connexions...</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>Infos nm-tray</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>à propos de %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; est une interface graphique simple basée sur Qt pour &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version : %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Connexion(s) active(s)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Réseau(x) Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Connexion(s) connue(s)</translation>
    </message>
</context>
</TS>
